@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Moo;
 use strictures 2;
@@ -18,21 +18,21 @@ use Music::Note;
 use Music::Tempo;
 
 
-has file => (
+has in_file => (
     is       => 'ro',
     isa      => sub { croak "File $_[0] does not exist!" unless -e $_[0] },
     required => 1,
 );
 
 
-has size => (
+has ngram_size => (
     is      => 'ro',
     isa     => \&_invalid_integer,
     default => sub { 2 },
 );
 
 
-has max => (
+has max_phrases => (
     is      => 'ro',
     isa     => \&_invalid_integer,
     default => sub { 10 },
@@ -66,7 +66,7 @@ has out_file => (
 );
 
 
-has pause => (
+has pause_duration => (
     is      => 'ro',
     isa     => sub { croak 'Invalid duration' unless $_[0] eq '' || $_[0] =~ /^[a-z]+$/ },
     default => sub { '' },
@@ -93,7 +93,7 @@ has weight => (
 );
 
 
-has randpatch => (
+has random_patch => (
     is      => 'ro',
     isa     => \&_invalid_boolean,
     default => sub { 0 },
@@ -107,7 +107,14 @@ has shuffle_phrases => (
 );
 
 
-has single => (
+has single_phrases => (
+    is      => 'ro',
+    isa     => \&_invalid_boolean,
+    default => sub { 0 },
+);
+
+
+has one_channel => (
     is      => 'ro',
     isa     => \&_invalid_boolean,
     default => sub { 0 },
@@ -134,7 +141,7 @@ sub process {
     # Counter for the tracks seen
     my $i = 0;
 
-    my $opus = MIDI::Opus->new({ from_file => $self->file });
+    my $opus = MIDI::Opus->new({ from_file => $self->in_file });
 
     my $analysis = "Ngram analysis:\n\tNum\tReps\tPhrase\n";
 
@@ -144,7 +151,7 @@ sub process {
         my @events = grep { $_->[0] eq 'note_on' && $_->[2] != 9 && $_->[4] != 0 } $t->events;
 
         # XXX Assume that there is one channel per track
-        my $track_channel = $events[0][2];
+        my $track_channel = $self->one_channel ? 0 : $events[0][2];
 
         # Skip if there are no events and no channel
         next unless @events && defined $track_channel;
@@ -168,7 +175,7 @@ sub process {
 
         # Parse the note text into ngrams
         my $ngram  = Lingua::EN::Ngram->new( text => $text );
-        my $phrase = $ngram->ngram( $self->size );
+        my $phrase = $ngram->ngram( $self->ngram_size );
 
         # Counter for the ngrams seen
         my $j = 0;
@@ -176,16 +183,16 @@ sub process {
         # Display the ngrams in order of their repetition amount
         for my $p ( sort { $phrase->{$b} <=> $phrase->{$a} || $a cmp $b } keys %$phrase ) {
             # Skip single occurance phrases if requested
-            next if !$self->single && $phrase->{$p} == 1;
+            next if !$self->single_phrases && $phrase->{$p} == 1;
 
             # Don't allow phrases that are not the right size
             my @items = grep { $_ } split /\s+/, $p;
-            next unless @items == $self->size;
+            next unless @items == $self->ngram_size;
 
             $j++;
 
             # End if we are past the maximum
-            last if $self->max > 0 && $j > $self->max;
+            last if $self->max_phrases > 0 && $j > $self->max_phrases;
 
             # Transliterate our letter code back to MIDI note numbers
             ( my $num = $p ) =~ tr/a-j/0-9/;
@@ -218,7 +225,7 @@ sub populate {
         for my $channel ( sort { $a <=> $b } keys %{ $self->notes } ) {
             # Create a function that adds notes to the score
             my $func = sub {
-                my $patch = $self->randpatch ? $self->_random_patch() : 0;
+                my $patch = $self->random_patch ? $self->_random_patch() : 0;
 
                 _set_chan_patch( $self->score, $channel, $patch );
 
@@ -239,8 +246,8 @@ sub populate {
                         $self->score->n( $duration, $note );
                     }
 
-                    $self->score->r( $self->pause )
-                        if $self->pause;
+                    $self->score->r( $self->pause_duration )
+                        if $self->pause_duration;
                 }
             };
 
@@ -276,18 +283,18 @@ sub populate {
                 my @phrase = split /\s/, $phrase;
                 push @all, @phrase;
                 push @all, 'r'
-                    if $self->pause;
+                    if $self->pause_duration;
             }
 
             # Create a function that adds our bucket of notes to the score
             my $func = sub {
-                my $patch = $self->randpatch ? $self->_random_patch() : 0;
+                my $patch = $self->random_patch ? $self->_random_patch() : 0;
 
                 _set_chan_patch( $self->score, $channel, $patch);
 
                 for my $note ( @all ) {
                     if ( $note eq 'r' ) {
-                        $self->score->r( $self->pause );
+                        $self->score->r( $self->pause_duration );
                     }
                     else {
                         my $duration = $self->durations->[ int rand @{ $self->durations } ];
@@ -393,16 +400,16 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
   use MIDI::Ngram;
   my $mng = MIDI::Ngram->new(
-    file      => 'eg/twinkle_twinkle.mid',
-    size      => 3,
-    patches   => [qw( 68 69 70 71 72 73 )],
-    randpatch => 1,
+    in_file      => 'eg/twinkle_twinkle.mid',
+    ngram_size   => 3,
+    patches      => [qw( 68 69 70 71 72 73 )],
+    random_patch => 1,
   );
   my $analysis = $mng->process;
   my $playback = $mng->populate;
@@ -414,15 +421,15 @@ C<MIDI::Ngram> parses a given MIDI file and finds the top repeated note phrases.
 
 =head1 ATTRIBUTES
 
-=head2 file
+=head2 in_file
 
 Required.  The MIDI file to process.
 
-=head2 size
+=head2 ngram_size
 
 Ngram phrase size.  Default: 2
 
-=head2 max
+=head2 max_phrases
 
 The maximum number of phrases to play.  Default: 10
 
@@ -436,14 +443,14 @@ The note durations to choose from (at random).  Default: [qn tqn]
 
 =head2 patches
 
-The patches to choose from (at random) if given the B<randpatch> option.
+The patches to choose from (at random) if given the B<random_patch> option.
 Otherwise 0 (piano) is used.  Default: [0 .. 127]
 
 =head2 out_file
 
 MIDI output file.  Default: midi-ngram.mid
 
-=head2 pause
+=head2 pause_duration
 
 Insert a rest of the given duration after each phrase.  Default: '' (no resting)
 
@@ -460,7 +467,7 @@ B<weight> option.  Default: 4
 
 Boolean.  Play phrases by their ngram repetition occurrence.  Default: 0
 
-=head2 randpatch
+=head2 random_patch
 
 Boolean.  Choose a random patch from B<patches> for each channel.
 Default: 0 (piano)
@@ -469,10 +476,14 @@ Default: 0 (piano)
 
 Boolean.  Shuffle the non-weighted phrases before playing them.  Default: 0
 
-=head2 single
+=head2 single_phrases
 
 Boolean.  Allow single occurrence ngrams.  Default: 0
 
+=head2 one_channel
+
+Boolean.  Accumulate phrases into a single list.  Default: 0
+
 =head2 score
 
 The MIDI score object.  Constructed at runtime.  Constructor argument if given
